@@ -1,6 +1,9 @@
+from typing import Optional
+
 from django.conf import settings
 from django.core import checks
 from django.db import models
+from django.forms import Field
 from django.utils.encoding import force_str
 from django.utils.translation import gettext_lazy as _
 
@@ -53,6 +56,11 @@ class PhoneNumberField(models.CharField):
     description = _("Phone number")
 
     def __init__(self, *args, region=None, **kwargs):
+        """
+        :keyword str region: 2-letter country code as defined in ISO 3166-1.
+            When not supplied, defaults to :setting:`PHONENUMBER_DEFAULT_REGION`
+        :keyword int max_length: The maximum length of the underlying char field.
+        """
         kwargs.setdefault("max_length", 128)
         super().__init__(*args, **kwargs)
         self._region = region
@@ -97,6 +105,9 @@ class PhoneNumberField(models.CharField):
 
         return super().get_prep_value(value)
 
+    def from_db_value(self, value, expression, connection):
+        return to_python(value)
+
     def contribute_to_class(self, cls, name, *args, **kwargs):
         super().contribute_to_class(cls, name, *args, **kwargs)
         setattr(cls, self.name, self.descriptor_class(self))
@@ -106,11 +117,19 @@ class PhoneNumberField(models.CharField):
         kwargs["region"] = self._region
         return name, path, args, kwargs
 
-    def formfield(self, **kwargs):
+    def formfield(
+        self,
+        form_class=None,
+        choices_form_class=None,
+        **kwargs,
+    ) -> Optional[Field]:
         defaults = {
-            "form_class": formfields.PhoneNumberField,
+            "form_class": (
+                formfields.PhoneNumberField if form_class is None else form_class
+            ),
             "region": self.region,
             "error_messages": self.error_messages,
+            "choices_form_class": choices_form_class,
         }
         defaults.update(kwargs)
         return super().formfield(**defaults)
