@@ -293,13 +293,6 @@ class PhoneNumberFieldTestCase(TestCase):
 
 
 class PhoneNumberFieldAppTest(TestCase):
-    @classmethod
-    def setUpClass(cls):
-        super().setUpClass()
-        # Drop alias with support for Django 3.2.
-        if django.VERSION < (4, 2):
-            cls.assertQuerySetEqual = cls.assertQuerysetEqual
-
     def test_save_field_to_database(self):
         """Basic Field Test"""
         tm = models.TestModel()
@@ -666,21 +659,41 @@ class RegionPhoneNumberModelFieldTest(TestCase):
     def test_region_field_renders_invalid_numbers(self):
         form = ARPhoneNumberForm({"phone": "abcdef"})
         self.assertFalse(form.is_valid())
-        aria_invalid = "" if django.VERSION[0] < 5 else 'aria-invalid="true" '
-        self.assertHTMLEqual(
-            form.as_p(),
-            '<ul class="errorlist">'
-            "<li>Enter a valid phone number (e.g. 011 2345-6789) "
-            "or a number with an international call prefix.</li>"
-            "</ul>"
-            "<p>"
-            '<label for="id_phone">Phone:</label>'
-            "<input "
-            'type="tel" '
-            'name="phone" '
-            'value="abcdef" '
-            'maxlength="128" '
-            f"{aria_invalid}"
-            'id="id_phone">'
-            "</p>",
-        )
+        if django.VERSION >= (5, 2):
+            self.assertHTMLEqual(
+                form.as_p(),
+                '<ul class="errorlist" id="id_phone_error">'
+                "<li>Enter a valid phone number (e.g. 011 2345-6789) "
+                "or a number with an international call prefix.</li>"
+                "</ul>"
+                "<p>"
+                '<label for="id_phone">Phone:</label>'
+                "<input "
+                'type="tel" '
+                'name="phone" '
+                'value="abcdef" '
+                'maxlength="128" '
+                'aria-describedby="id_phone_error" '
+                'aria-invalid="true" '
+                'id="id_phone">'
+                "</p>",
+            )
+        else:
+            aria_invalid = "" if django.VERSION[0] < 5 else 'aria-invalid="true" '
+            self.assertHTMLEqual(
+                form.as_p(),
+                '<ul class="errorlist">'
+                "<li>Enter a valid phone number (e.g. 011 2345-6789) "
+                "or a number with an international call prefix.</li>"
+                "</ul>"
+                "<p>"
+                '<label for="id_phone">Phone:</label>'
+                "<input "
+                'type="tel" '
+                'name="phone" '
+                'value="abcdef" '
+                'maxlength="128" '
+                f"{aria_invalid}"
+                'id="id_phone">'
+                "</p>",
+            )
